import pytest

from jaraco import clipboard


def needs_command(name):
	cmd = vars(clipboard)[name]

	return pytest.mark.xfail(
		cmd is clipboard._not_implemented,
		reason="{name} not implemented on this platform",
	)


@needs_command("copy_text")
def test_copy_text():
	clipboard.copy_text("foo")


@needs_command("paste_text")
def test_paste_text():
	# first ensure there's something on the clipboard:
	clipboard.copy_text('test for paste')
	assert clipboard.paste_text() == 'test for paste'



import platform
import importlib
import itertools

_platform_mod_name = '.' + platform.system()
_platform_mod = importlib.import_module(_platform_mod_name, 'jaraco.clipboard')

# support copy and paste of text, html, and image.
_modes = 'copy', 'paste'
_formats = 'text', 'html', 'image'
_methods = map('_'.join, itertools.product(_modes, _formats))

def _not_implemented(*args, **kwargs):
	raise NotImplementedError("format not supported")

for name in _methods:
	func = getattr(_platform_mod, name, _not_implemented)
	globals().update({name: func})

copy = copy_text
paste = paste_text

__all__ = [
	name for name, func in globals().items()
	if callable(func) and not name.startswith('_')
]



import pyperclip

copy_text, paste_text = pyperclip.determine_clipboard()

unavailable = any(
	isinstance(func, object)
	and type(func).__name__ == 'ClipboardUnavailable'
	for func in locals().values()
)

if unavailable:
	del copy_text
	del paste_text
